Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(1208)

Unified Diff: Source/core/html/parser/HTMLScriptRunner.cpp

Issue 15856002: First step of HTMLImports (Closed) Base URL: svn://svn.chromium.org/blink/trunk
Patch Set: Fixed Mac build Created 7 years, 7 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « Source/core/html/parser/HTMLScriptRunner.h ('k') | Source/core/tests/LinkRelAttribute.cpp » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: Source/core/html/parser/HTMLScriptRunner.cpp
diff --git a/Source/core/html/parser/HTMLScriptRunner.cpp b/Source/core/html/parser/HTMLScriptRunner.cpp
index f3a0f32e6be7b529382b55e8291989b678742224..d5ca07ccd05ab7b049e6c80266b0d5c795909ec0 100644
--- a/Source/core/html/parser/HTMLScriptRunner.cpp
+++ b/Source/core/html/parser/HTMLScriptRunner.cpp
@@ -48,7 +48,7 @@ HTMLScriptRunner::HTMLScriptRunner(Document* document, HTMLScriptRunnerHost* hos
: m_document(document)
, m_host(host)
, m_scriptNestingLevel(0)
- , m_hasScriptsWaitingForStylesheets(false)
+ , m_hasScriptsWaitingForResources(false)
{
ASSERT(m_host);
}
@@ -98,8 +98,8 @@ ScriptSourceCode HTMLScriptRunner::sourceFromPendingScript(const PendingScript&
bool HTMLScriptRunner::isPendingScriptReady(const PendingScript& script)
{
- m_hasScriptsWaitingForStylesheets = !m_document->haveStylesheetsLoaded();
- if (m_hasScriptsWaitingForStylesheets)
+ m_hasScriptsWaitingForResources = !m_document->haveStylesheetsAndImportsLoaded();
+ if (m_hasScriptsWaitingForResources)
return false;
if (script.cachedScript() && !script.cachedScript()->isLoaded())
return false;
@@ -110,7 +110,7 @@ void HTMLScriptRunner::executeParsingBlockingScript()
{
ASSERT(m_document);
ASSERT(!isExecutingScript());
- ASSERT(m_document->haveStylesheetsLoaded());
+ ASSERT(m_document->haveStylesheetsAndImportsLoaded());
ASSERT(isPendingScriptReady(m_parserBlockingScript));
InsertionPointRecord insertionPointRecord(m_host->inputStream());
@@ -203,14 +203,14 @@ void HTMLScriptRunner::executeScriptsWaitingForLoad(CachedResource* cachedScript
executeParsingBlockingScripts();
}
-void HTMLScriptRunner::executeScriptsWaitingForStylesheets()
+void HTMLScriptRunner::executeScriptsWaitingForResources()
{
ASSERT(m_document);
// Callers should check hasScriptsWaitingForStylesheets() before calling
// to prevent parser or script re-entry during </style> parsing.
- ASSERT(hasScriptsWaitingForStylesheets());
+ ASSERT(hasScriptsWaitingForResources());
ASSERT(!isExecutingScript());
- ASSERT(m_document->haveStylesheetsLoaded());
+ ASSERT(m_document->haveStylesheetsAndImportsLoaded());
executeParsingBlockingScripts();
}
« no previous file with comments | « Source/core/html/parser/HTMLScriptRunner.h ('k') | Source/core/tests/LinkRelAttribute.cpp » ('j') | no next file with comments »
@@ -203,14 +203,14 @@ void HTMLScriptRunner::executeScriptsWaitingForLoad(CachedResource* cachedScript
{
ASSERT(m_document);
- // Callers should check hasScriptsWaitingForStylesheets() before calling
+ // Callers should check hasScriptsWaitingForResources() before calling
// to prevent parser or script re-entry during </style> parsing.

Powered by Google App Engine
This is Rietveld 408576698